Skip to contents

A function which formats the exercise numbers and code chunk labels correctly. check_current_tutorial() reads in the tutorial which is in the active editor window in Positron. It determines what the number of each exercise should be and fixes any mistakes. It ensures that all code chunk labels are the correct function of the section title and exercise number.

Usage

check_current_tutorial()

Value

No return value, called for the side effect of rewriting the tutorial file in the active editor window.