write_answers: Write tutorial answers to file

View source: R/write_answers.R

write_answersR Documentation

Write tutorial answers to file

Description

Take a tutorial session (or a submission list), extract all submitted answers, and write out an HTML file with those answers.

Usage

write_answers(file, obj)

Arguments

file

Output file path (should end in .html).

obj

Either a Shiny session object (from learnr) or a list of submissions (as returned by get_submissions_from_learnr_session()).

Value

No return value, called for the side effect of writing an HTML file of submitted answers to file.


tutorial.helpers documentation built on July 27, 2026, 9:06 a.m.