View source: R/write_answers.R
| write_answers | R Documentation |
Take a tutorial session (or a submission list), extract all submitted answers, and write out an HTML file with those answers.
write_answers(file, obj)
file |
Output file path (should end in .html). |
obj |
Either a Shiny session object (from learnr) or a list of submissions (as returned by get_submissions_from_learnr_session()). |
No return value, called for the side effect of writing an HTML
file of submitted answers to file.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.